@@ -12,7 +12,7 @@ from requests_oauthlib import OAuth1
 from query import Resolve, Table, Submit, Insert, Facets, Flag, Geopulse, Geocode, Diffs, Match, Multi, Clear
 
 API_V3_HOST = "http://api.v3.factual.com"
-DRIVER_VERSION_TAG = "factual-python-driver-1.4.1"
+DRIVER_VERSION_TAG = "factual-python-driver-1.4.2"
 
 class Factual(object):
     def __init__(self, key, secret, timeout=None):
@@ -55,7 +55,7 @@ class Factual(object):
         return Flag(self.api, table, factual_id)
 
     def geopulse(self, point={}):
-        return Geopulse(self.api, 'places/geopulse', {'geo': point})
+        return Geopulse(self.api, 'geopulse/context', {'geo': point})
 
     def geocode(self, point):
         return Geocode(self.api, 'places/geocode', {'geo': point})
