@@ -65,7 +65,7 @@ class FactualAPITestSuite(unittest.TestCase):
         self.assertEqual(20, included_rows)
 
     def test_resolve(self):
-        q = self.factual.resolve({'name': 'factual inc', 'locality': 'los angeles'})
+        q = self.factual.resolve('places-v3', {'name': 'factual inc', 'locality': 'los angeles'})
         row = q.data()[0]
         self.assertTrue(row['resolved'])
         self.assertEqual('1801 Avenue Of The Stars', row['address'])
@@ -78,7 +78,7 @@ class FactualAPITestSuite(unittest.TestCase):
 
     def test_schema(self):
         schema = self.places.schema()
-        self.assertEqual(22, len(schema['fields']))
+        self.assertGreater(len(schema['fields']),20)
         self.assertIn('title', schema)
         self.assertIn('locality', set(f['name'] for f in schema['fields']))
 
@@ -104,6 +104,12 @@ class FactualAPITestSuite(unittest.TestCase):
         self.assertEqual('US', row['country'].upper())
         self.assertRegexpMatches(row['website'], 'http')
 
+    def test_includes(self):
+        q = self.places.filters({'category_ids':{'$includes':10}})
+        rows = q.data()
+        for row in rows:
+            self.assertIn(10, row['category_ids'])
+
     def test_raw_read(self):
         # filters here is url encoded {"name":"Starbucks"}
         response = self.factual.raw_read('t/places/read', 'limit=15&filters=%7B%22name%22%3A%22Starbucks%22%7D')
@@ -140,20 +146,26 @@ class FactualAPITestSuite(unittest.TestCase):
         self.assertTrue(region['tx'] > 200)
 
     def test_facets_geo(self):
-        q = self.facets.select("category").geo(circle(34.06018, -118.41835, 5000))
-        category = q.data()['category']
-        self.assertTrue(category['shopping'] > 1000)
-        self.assertTrue(category['health & medicine > physicians'] > 1000)
+        q = self.facets.select("locality").geo(circle(34.06018, -118.41835, 1000))
+        locality = q.data()['locality']
+        self.assertTrue(locality['los angeles'] > 3000)
+        self.assertTrue(locality['beverly hills'] > 500)
 
     def test_geopulse(self):
         geopulse = self.factual.geopulse(point(34.06021, -118.41828))
         income_only = geopulse.select('income')
-        all_results = geopulse.data()[0]
-        income_results = income_only.data()[0]
-        self.assertIn('commercial_density', all_results)
-        self.assertTrue(0 <= all_results['commercial_density'] <= 1)
-        self.assertEqual(1, len(income_results))
-        self.assertIn('income', income_results)
+        all_results = geopulse.data()
+        income_results = income_only.data()
+        self.assertIn('demographics', all_results)
+        demographics = all_results['demographics']
+        self.assertIn('area_statistics', demographics)
+        area_statistics = demographics['area_statistics']
+        self.assertIn('commercial_residential', area_statistics)
+        commercial_residential = area_statistics['commercial_residential']
+        self.assertTrue(0 <= commercial_residential['business'] <= 100)
+        income_demographics = income_results['demographics']
+        self.assertEqual(1, len(income_demographics))
+        self.assertIn('income', income_demographics)
 
     def test_geocode(self):
         geocode = self.factual.geocode(point(34.06021, -118.41828))
@@ -209,9 +221,9 @@ class FactualAPITestSuite(unittest.TestCase):
         self.assertItemsEqual(batch, streamed)
 
     def test_match(self):
-        match = self.factual.match({'name':'McDonalds','address':'10451 Santa Monica Blvd','locality':'Los Angeles','region':'CA'})
+        match = self.factual.match('places-v3', {'name':'McDonalds','address':'10451 Santa Monica Blvd','locality':'Los Angeles','region':'CA'})
         match_id = match.get_id()
-        self.assertEqual('bd886f67-9d86-40c5-9217-f7bcd53cfc0e', match_id)
+        self.assertEqual('c730d193-ba4d-4e98-8620-29c672f2f117', match_id)
 
     def test_multi(self):
         q1 = self.factual.table('places').filters({'postcode':'90067'})
@@ -219,5 +231,9 @@ class FactualAPITestSuite(unittest.TestCase):
         response = self.factual.multi({'query1':q1,'query2':q2})
         self.assertTrue('query1' in response and 'query2' in response)
 
+    def test_get_row(self):
+        row = self.factual.get_row('places', '03c26917-5d66-4de9-96bc-b13066173c65')
+        self.assertEqual('Factual', row['name'])
+
 if __name__ == '__main__':
     unittest.main()
